/******************************************************************************
* C Source: Extraction_List                                                   *
*                                                                             *
* File:                                                                       *
*    extrctlst.c                                                              *
*                                                                             *
* Description:                                                                *
*    This set of functions performs various manipulations on a linked list    *
*    (see lnkd_lst.c and lnkd_lst.h ) of Extractions (see extrctn.c and       *
*    extrctn.h), each node for an individual extraction. (see extrtlst.h).    *
*                                                                             *
* Module List:                                                                *
*    Add_Extraction_to_List                                                   *
*       Insert an extraction into the top of an extraction list.              *
*    Check_Disc_Extraction_List_Disc                                          *
*       Compare disc number with that of the extractions in a list for a      *
*       CD-ROM.                                                               *
*    Compare_Extraction_Lists                                                 *
*       Compare two extraction lists.                                         *
*    Create_Empty_Extraction_List                                             *
*       Create a new empty extraction list.                                   *
*    Delete_Extraction_List                                                   *
*       Delete the linked list for an extraction list, but not the extraction *
*       data the list points to.                                              *
*    Delete_Extraction_List_Data                                              *
*       Delete the linked list for an extraction list, AND the extraction     *
*       data the list points to.                                              *
*    Extraction_List_Is_Empty                                                 *
*       Returns TRUE if extraction list is empty, othewise, returns False.    *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#include <stdio.h>

#include "extrtlst.h"

#include "extrctn.h"
#include "generic.h"
#include "lnkd_lst.h"

/******************************************************************************
* Module:                                                                     *
*    Add_Extraction_to_List                                                   *
*                                                                             *
* File:                                                                       *
*    extrtlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Adds an extractin to the top of an extraction list.                      *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          X_LIST, Reference                                                  *
*             The extraction list to which we're adding the extraction.       *
*       Extraction                                                            *
*          EXTRACTION, Reference                                              *
*             The extraction we're adding to the extraction list.             *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**************************************
* Add_Extraction_to_List declarations *
**************************************/
void       Add_Extraction_to_List( List, Extraction )
X_LIST     List      ;
EXTRACTION Extraction;
{
/***********************************************
* Add_Extraction_to_List begin executable code *
***********************************************/
   Insert_Linked_List_Data( List, Extraction );

   return;
}
/*********************************************
* Add_Extraction_to_List end executable code *
*********************************************/

/******************************************************************************
* Module:                                                                     *
*    Check_Disc_Extraction_List_Disc                                          *
*                                                                             *
* File:                                                                       *
*    extrtlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Compare a disc number with that of an extraction list constructed for a  *
*    single CD-ROM disc.                                                      *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          X_LIST, Reference                                                  *
*             The extraction list we're checking.                             *
*       Disc                                                                  *
*          int, Reference                                                     *
*             The disc number we're comparing against the extraction list.    *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/***********************************************
* Check_Disc_Extraction_List_Disc declarations *
***********************************************/
int    Check_Disc_Extraction_List_Disc( List, Disc )
X_LIST List;
int*   Disc;
{
   int List_Disc; /* The disc number of the extraction list */

/********************************************************
* Check_Disc_Extraction_List_Disc begin executable code *
********************************************************/
   List_Disc = ( ( EXTRACTION )( List->Top->Data ) )->Plate->Disc;

   return ( List_Disc - *Disc );
}
/******************************************************
* Check_Disc_Extraction_List_Disc end executable code *
******************************************************/

/******************************************************************************
* Module:                                                                     *
*    Compare_Extraction_Lists                                                 *
*                                                                             *
* File:                                                                       *
*    extrtlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Compare the extractions in two extraction lists. The result of the       *
*    comparison of the first different extractions is returned. If no         *
*    different extractions are found, then zero is returned.                  *
*                                                                             *
* Return Value:                                                               *
*    int: The result of the comparison.                                       *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List_1                                                                *
*          X_LIST, Reference                                                  *
*             The first list we're comparing.                                 *
*       List_2                                                                *
*          X_LIST, Reference                                                  *
*             The second list we're comparing.                                *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/****************************************
* Compare_Extraction_Lists declarations *
****************************************/
int    Compare_Extraction_Lists( List_1, List_2 )
X_LIST List_1;
X_LIST List_2;
{
   XL_NODE List_1_Node; /* Node in first extraction list  */
   XL_NODE List_2_Node; /* Node in second extraction list */

   EXTRACTION List_1_Extraction; /* Extraction from first list  */
   EXTRACTION List_2_Extraction; /* Extraction from second list */

   int Comparison; /* Result of the comparison */

/*************************************************
* Compare_Extraction_Lists begin executable code *
*************************************************/
   List_1_Node = List_1->Top;
   List_2_Node = List_2->Top;

   while ( ( List_1_Node != NULL ) && ( List_2_Node != NULL ) )
   {
      List_1_Extraction = ( EXTRACTION )List_1_Node->Data;
      List_2_Extraction = ( EXTRACTION )List_2_Node->Data;


/**********************************
* Compare_Extraction_Lists page 2 *
**********************************/

      Comparison = Compare_Extractions( List_1_Extraction, List_2_Extraction );

      if ( Comparison != 0 )
         return Comparison;
      List_1_Node = List_1_Node->Next;
      List_2_Node = List_2_Node->Next;
   }

   if ( List_1_Node != NULL )
      return -1;
   else if ( List_2_Node != NULL )
      return 1;
   else
      return 0;
}
/***********************************************
* Compare_Extraction_Lists end executable code *
***********************************************/

/******************************************************************************
* Module:                                                                     *
*    Create_Empty_Extraction_List                                             *
*                                                                             *
* File:                                                                       *
*    extrtlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Create a new empty extraction list, allocating memory for the header.    *
*                                                                             *
* Return Value:                                                               *
*    X_LIST: The newly created extraction.                                    *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       none                                                                  *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/********************************************
* Create_Empty_Extraction_List declarations *
********************************************/
X_LIST Create_Empty_Extraction_List()
{
/*****************************************************
* Create_Empty_Extraction_List begin executable code *
*****************************************************/
   return ( X_LIST )Create_Empty_Linked_List();
}
/***************************************************
* Create_Empty_Extraction_List end executable code *
***************************************************/

/******************************************************************************
* Module:                                                                     *
*    Delete_Extraction_List                                                   *
*                                                                             *
* File:                                                                       *
*    extrtlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Free memory allocated for an extraction list, but not the data it points *
*    to.                                                                      *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          X_LIST, Reference                                                  *
*             The extraction list we're deleting from memory.                 *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**************************************
* Delete_Extraction_List declarations *
**************************************/
void Delete_Extraction_List( List )
X_LIST List;
{
/***********************************************
* Delete_Extraction_List begin executable code *
***********************************************/
   Delete_Linked_List( List );

   return;
}
/*********************************************
* Delete_Extraction_List end executable code *
*********************************************/

/******************************************************************************
* Module:                                                                     *
*    Delete_Extraction_List_Data                                              *
*                                                                             *
* File:                                                                       *
*    extrtlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Free memory allocated for extraction list, but AND the data it points    *
*    to.                                                                      *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          X_LIST, Reference                                                  *
*             The extraction list we're deleting from memory.                 *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*******************************************
* Delete_Extraction_List_Data declarations *
*******************************************/
void   Delete_Extraction_List_Data( List )
X_LIST List;
{
/****************************************************
* Delete_Extraction_List_Data begin executable code *
****************************************************/
   Delete_Linked_List_Data( List, Delete_Extraction );

   return;
}
/**************************************************
* Delete_Extraction_List_Data end executable code *
**************************************************/

/******************************************************************************
* Module:                                                                     *
*    Extraction_List_Is_Empty                                                 *
*                                                                             *
* File:                                                                       *
*    extrtlst.c                                                               *
*                                                                             *
* Description:                                                                *
*   Returns TRUE if extraction list is empty, othewise, returns False.        *
*                                                                             *
* Return Value:                                                               *
*   BOOL: TRUE if extraction list is empty.                                   *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          X_LIST, Reference                                                  *
*             The extraction list we're deleting from memory.                 *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-DEC-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/****************************************
* Extraction_List_Is_Empty declarations *
****************************************/
BOOL   Extraction_List_Is_Empty( List )
X_LIST List;
{
/*************************************************
* Extraction_List_Is_Empty begin executable code *
*************************************************/
   return Linked_List_Is_Empty( List );
}
/***********************************************
* Extraction_List_Is_Empty end executable code *
***********************************************/
